summaryrefslogtreecommitdiff
path: root/src/mesa/swrast/s_alpha.c
diff options
context:
space:
mode:
authorBrian Paul <brian.paul@tungstengraphics.com>2003-03-25 02:23:44 +0000
committerBrian Paul <brian.paul@tungstengraphics.com>2003-03-25 02:23:44 +0000
commit45bc887da226403f2c41077e40ca38b6f60f1359 (patch)
tree831190e41ee62449b751e82ab259797bced40524 /src/mesa/swrast/s_alpha.c
parentaf1bfb7281eb8175adb7bb9774aeafa020e3831b (diff)
replace _mesa_ prefix with _swrast_, remove s_histogram.[ch]
Diffstat (limited to 'src/mesa/swrast/s_alpha.c')
-rw-r--r--src/mesa/swrast/s_alpha.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mesa/swrast/s_alpha.c b/src/mesa/swrast/s_alpha.c
index 35ec7e9dcc..9ad3ea3b12 100644
--- a/src/mesa/swrast/s_alpha.c
+++ b/src/mesa/swrast/s_alpha.c
@@ -1,4 +1,4 @@
-/* $Id: s_alpha.c,v 1.13 2003/03/01 01:50:25 brianp Exp $ */
+/* $Id: s_alpha.c,v 1.14 2003/03/25 02:23:44 brianp Exp $ */
/*
* Mesa 3-D graphics library
@@ -39,14 +39,14 @@
/**
* \fn GLint _mesa_alpha_test( const GLcontext *ctx, struct sw_span *span )
* \brief Apply the alpha test to a span of pixels.
* \return
* - "0" = all pixels in the span failed the alpha test.
* - "1" = one or more pixels passed the alpha test.
*/
GLint
-_mesa_alpha_test( const GLcontext *ctx, struct sw_span *span )
+_swrast_alpha_test( const GLcontext *ctx, struct sw_span *span )
{
const GLchan (*rgba)[4] = (const GLchan (*)[4]) span->array->rgba;
GLchan ref;
@@ -91,7 +91,7 @@ _mesa_alpha_test( const GLcontext *ctx, struct sw_span *span )
span->writeAll = GL_FALSE;
return 0;
default:
- _mesa_problem( ctx, "Invalid alpha test in _mesa_alpha_test" );
+ _mesa_problem( ctx, "Invalid alpha test in _swrast_alpha_test" );
return 0;
}
}
@@ -39,14 +39,14 @@
/**
- * \fn GLint _mesa_alpha_test( const GLcontext *ctx, struct sw_span *span )
+ * \fn GLint _swrast_alpha_test( const GLcontext *ctx, struct sw_span *span )
* \brief Apply the alpha test to a span of pixels.
* \return